@@ -20,7 +20,7 @@ use Carp;
 
 
 our @ISA     = qw(Exporter);
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 our $AUTOLOAD;
 
 
@@ -54,6 +54,8 @@ sub new {
         _font_family      => 2,
         _font_charset     => 0,
         _font_scheme      => 'minor',
+        _theme            => 0,
+        _hyperlink        => 0,
 
         _hidden => 0,
         _locked => 1,
@@ -557,6 +559,25 @@ sub set_rotation {
 }
 
 
+###############################################################################
+#
+# set_hyperlink()
+#
+# Set the properties for the hyperlink style. TODO. This doesn't currently
+# work. Fix it when styles are supported.
+#
+sub set_hyperlink {
+
+    my $self = shift;
+
+    $self->{_hyperlink} = 1;
+
+    $self->set_underline( 1 );
+    $self->set_theme( 10 );
+    $self->set_align( 'top' );
+}
+
+
 ###############################################################################
 #
 # set_format_properties()
