@@ -20,7 +20,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 our $schema_root     = 'http://schemas.openxmlformats.org';
 our $package_schema  = $schema_root . '/package/2006/relationships';
@@ -109,6 +109,28 @@ sub _add_package_relationship {
 }
 
 
+
+###############################################################################
+#
+# _add_worksheet_relationship()
+#
+# Add worksheet relationship to sheet.rels xml files.
+#
+sub _add_worksheet_relationship {
+
+    my $self        = shift;
+    my $type        = shift;
+    my $target      = shift;
+    my $target_mode = shift;
+
+    $type   = $document_schema . $type;
+    $target = $target;
+
+    push @{ $self->{_rels} }, [ $type, $target, $target_mode ];
+}
+
+
+
 ###############################################################################
 #
 # Internal methods.
@@ -157,9 +179,10 @@ sub _write_relationships {
 #
 sub _write_relationship {
 
-    my $self   = shift;
-    my $type   = shift;
-    my $target = shift;
+    my $self        = shift;
+    my $type        = shift;
+    my $target      = shift;
+    my $target_mode = shift;
 
     my @attributes = (
         'Id'     => 'rId' . $self->{_id}++,
@@ -167,6 +190,8 @@ sub _write_relationship {
         'Target' => $target,
     );
 
+    push @attributes, ( 'TargetMode' => $target_mode ) if $target_mode;
+
     $self->{_writer}->emptyTag( 'Relationship', @attributes );
 }
 
